'use strict';

var _eslint = require('eslint');

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var processHTML = {
  preprocess: function preprocess(text, filename) {
    var config = new _eslint.CLIEngine({ useEslintrc: true }).getConfigForFile(_path2.default.resolve(filename));
    var quote = config.rules.quotes[1] === 'double' ? '"' : '\'';
    text = text;
    var processed = text
    // replace jinja comments with js comments
    .replace(/\{#([\s\S]*?)#\}/g, function (str, val) {
      return '/*' + val + '*/';
    })
    // treat if-else statement as ( ... , ... )
    .replace(/\{%(-?\s*if.*?)%\}/g, function (str, val) {
      return '(/*' + val.substr(1) + '*/';
    }).replace(/\{%(-?\s*(else|elif).*?)%\}/g, function (str, val) {
      return ',/*' + val.substr(1) + '*/';
    }).replace(/\{%(-?\s*endif\s*-?)%\}/g, function (str, val) {
      return '/*' + val.substr(1) + '*/)';
    })
    // replace jinja statements with js comments
    .replace(/\{%(.*?)%\}/g, function (str, val) {
      return '/*' + val + '*/';
    })
    // replace jinja expression tags in strings with spaces
    .replace(/\{[{%]([\s\S]*?)[}%]\}/g, function (str) {
      return str.replace(/['"]/g, ' ');
    }).replace(/(['"])(.*?)\1/g, function (str) {
      return str.replace(/(\{\{|\}\})/g, '  ');
    })
    // replace jinja expressions with strings
    .replace(/\{\{(.*?)\}\}/g, function (str, val) {
      return quote + ' ' + val + ' ' + quote;
    });
    return [processed];
  },
  postprocess: function postprocess(messages) {
    return messages[0];
  }
};

module.exports = {
  processors: {
    '.js': processHTML,
    '.html': processHTML,
    '.htm': processHTML
  }
};